# ==========================================================================================================================================
# Repository path:    $HeadURL: https://90.145.156.222/DMS-Houtribdijk/code/nc-checks/src/checks/checkDMS_abs.py $
# Last committed:     $Revision: 539724 $
#                     $Author: jansink $
#                     $Date: 2020-02-18 13:48:17 +0100 (di, 18 feb 2020) $
#
# Copyright © 2019, ®HKV services, All Rights Reserved.
# ==========================================================================================================================================

import pandas as pd
import datetime
from .checkParameter import checkParameter


def checkDMS_abs(logger, thredds_data, filename):

    df = pd.DataFrame(columns=['Opwerking', 'Instrument',
                               'Location', 'Parameter', 'Date', 'Nc', 'inRange', 'errStr'])

    checklist = pd.read_csv(filename, skiprows=0, sep=";", header=0)

    now = pd.to_datetime(pd.datetime.now().strftime('%Y-%m-%d'))

    # loop over checks
    for i in range(len(checklist)):

        opwerking = checklist['Opwerking'][i]
        inst = checklist['Instrument'][i]
        loc = checklist['Location'][i]
        parName = checklist['Parameter'][i]

        begindays = int(checklist['Begintime'][i])
        t1 = now + pd.to_timedelta(begindays, unit='d')
        enddays = int(checklist['Endtime'][i])
        t2 = now + pd.to_timedelta(enddays, unit='d')

        t = t1
        dt = checklist['Timestep'][i]

        lowerLimit = checklist['Lower'][i]
        upperLimit = checklist['Upper'][i]
        errorValue = checklist['Errorvalue'][i]

        while 1:

            if t >= t2:
                break

            datestr = '{0:04}'.format(t.year) + '{0:02}'.format(t.month) + \
                '{0:02}'.format(t.day) + '{0:02}'.format(t.hour) + '0000'
            nc_f = thredds_data + opwerking + '/'+inst+'/' + \
                loc + '/'+inst+'_' + loc + '_' + datestr + '.nc'

            inRange, errStr = checkParameter(
                nc_f, parName, lowerLimit, upperLimit, errorValue)

            logger.info(opwerking+';'+inst+';'+loc+';'+parName +
                        ';'+nc_f+';'+str(inRange)+';'+errStr+'\n')

            row = [opwerking, inst, loc, parName,
                   datestr, nc_f, str(inRange), errStr]
            df.loc[len(df)] = row

            t = t+datetime.timedelta(hours=int(dt))

    return df
